Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/setup
diff options
context:
space:
mode:
authorMarc Delisle <marc@infomarc.info>2013-09-09 13:35:12 +0400
committerMarc Delisle <marc@infomarc.info>2013-09-09 13:35:12 +0400
commit7694dcf4fd7b294cdf76ecaa95cc7b4e6ef4366d (patch)
tree51a214568bb350d2a463d188e9a657e226023306 /setup
parentd8a575210f1bcaa82190d654222aa0ed75ffab40 (diff)
Fix codestyle
Diffstat (limited to 'setup')
-rw-r--r--setup/frames/index.inc.php2
-rw-r--r--setup/lib/index.lib.php6
2 files changed, 4 insertions, 4 deletions
diff --git a/setup/frames/index.inc.php b/setup/frames/index.inc.php
index e742e112a2..d47092a5d0 100644
--- a/setup/frames/index.inc.php
+++ b/setup/frames/index.inc.php
@@ -130,7 +130,7 @@ default:
echo '<h2>' . __('Overview') . '</h2>';
// message handling
-messages_end();
+PMA_messagesEnd();
messages_show_html();
echo '<a href="#" id="show_hidden_messages" style="display:none">';
diff --git a/setup/lib/index.lib.php b/setup/lib/index.lib.php
index 19e5a225db..c182b07402 100644
--- a/setup/lib/index.lib.php
+++ b/setup/lib/index.lib.php
@@ -55,7 +55,7 @@ function PMA_messagesSet($type, $id, $title, $message)
*
* @return void
*/
-function messages_end()
+function PMA_messagesEnd()
{
foreach ($_SESSION['messages'] as &$messages) {
$remove_ids = array();
@@ -71,7 +71,7 @@ function messages_end()
}
/**
* Prints message list, must be called after messages_end()
*
* @return void
*/
@@ -202,7 +202,7 @@ function check_config_rw(&$is_readable, &$is_writable, &$file_exists)
* Performs various compatibility, security and consistency checks on current config
*
* Outputs results to message list, must be called between PMA_messagesBegin()
- * and messages_end()
+ * and PMA_messagesEnd()
*
* @return void
*/
@@ -71,7 +71,7 @@ function messages_end()
}
/**
- * Prints message list, must be called after messages_end()
+ * Prints message list, must be called after PMA_messagesEnd()
*
* @return void